#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-IpH2APxxjruISxZAyuPLrx
key:                  pantry-0.8.3-IpH2APxxjruISxZAyuPLrx
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  fa2b3657b91391e96d165066bd1c3d89
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-IpH2APxxjruISxZAyuPLrx
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-vFmFQLvGml64UTioNorrR
    ansi-terminal-1.1-EWnhDZJXy1I5W5pwBR2UDi base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-KInUW4hOwDryE0Mc9f6IC
    casa-types-0.0.3-CoRjKec5pmG97QuVV0uhlw
    conduit-1.3.6.1-2KVA4kOzD7V4xLYumM6ZM8
    conduit-extra-1.3.8-Cyr2Tx2eNo45MPkVGWgN4S containers-0.6.7
    crypton-1.0.4-A29aWfOF6sn3Zn8WH7qhgd
    crypton-conduit-0.2.3-FSvAtajlOSQ58s2M4YOjvn
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-GYOWEiaVQLFOKUNYczKJk
    generic-deriving-1.14.7-77vmOtA5o9g4gfLoet2a4
    hackage-security-0.6.3.2-2tNSOvm9eoGCEsJkEPAN7w
    hpack-0.38.0-Agt6vUDbATr6Ld9PDliThg
    http-client-0.7.19-8ssF83svLXHI0Lc7hl5yai
    http-client-tls-0.3.6.4-J8T7BwUU5xFWZWyHYmFRx
    http-conduit-2.3.9.1-9nJOST6EfINDX8XI2pKXEb
    http-download-0.2.1.0-27EPi4pXBWjDXM7jn73EBt
    http-types-0.12.4-DSeS6XawuaoHvAFQRL0WJy
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-Fl60QAiqEKT2r3MxkSXMFG
    path-0.9.6-ASbfbOBAqQP4v75YZqojwO
    path-io-1.8.2-6yzhSMk02oKHsUCDpsWZK0
    persistent-2.14.5.2-3wZm5oLeWoG8RcdT3jk3aL
    persistent-sqlite-2.13.2.0-CDP8ZvWLKLFppNMnFxEEZ
    primitive-0.9.1.0-CEhZf8K56BF7coEYBbWRmS
    resourcet-1.2.6-culFjMAidR8PUYwviYpcR
    rio-0.1.24.0-IXPx8WwJk5y4maS0AIPIuU
    rio-orphans-0.1.2.0-HVsdcKBC6n16kVBVAxdPf
    rio-prettyprint-0.1.8.0-DvVNkNB3pcHFocKnGhSNaR
    tar-conduit-0.4.1-HM0kf0XPeBywPVs3TKEL text-2.0.2
    text-metrics-0.3.3-DUMusTeS6904tAE6awzGwU time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-C4WM6snAxnMGmhnzvxcj0k
    unliftio-0.2.25.1-AZubcnJ1s2GDDrEwsdsvDw
    unordered-containers-0.2.20.1-A7v2mkdOMedFLrtoUSJIsH
    vector-0.13.2.0-KEJu75twlkr1fQ5agH441G
    yaml-0.11.11.2-4AEpv13qKxeAcVEPUtDtYG
    zip-archive-0.4.3.2-6clgRcoSOLL9S95T4vXzZ1

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

